"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasPermissions = void 0;
/**
 * Determines if the user has permissions, based on the permission kind value
 */
exports.hasPermissions = function (permissionMask, permissions) {
    if (permissions === void 0) { permissions = []; }
    // Method to ensure the core library is loaded
    var load = function () {
        // Return a promise
        return new Promise(function (resolve, reject) {
            // See if the core lib is loaded
            if (window["SP"] && window["SP"].BasePermissions) {
                resolve();
            }
            // Else, wait for the core script to be loaded
            else {
                window["SP"].SOD.executeFunc("sp.js", "SP.BasePermissions", function () { resolve(); });
            }
        });
    };
    // Return a promise
    return new Promise(function (resolve) {
        // Ensure the core lib is loaded
        load().then(function () {
            var hasPermissions = false;
            // Set the permissions
            var requestedPermissions = typeof (permissions) === "number" ? [permissions] : permissions;
            // Initialize the base permissions from the value
            var basePermissions = new SP.BasePermissions();
            basePermissions.initPropertiesFromJson(permissionMask);
            // Default the permission flag
            hasPermissions = true;
            // Parse the requested permissions
            for (var i = 0; i < requestedPermissions.length; i++) {
                // See if the user has permissions
                if (!basePermissions.has(requestedPermissions[i])) {
                    // Set the flag and break from the loop
                    hasPermissions = false;
                    break;
                }
            }
            // Resolve the promise
            resolve(hasPermissions);
        });
    });
};
